@@ -323,12 +323,13 @@ class RoborockClient:
     @fallback_cache
     async def get_prop(self) -> DeviceProp | None:
         """Gets device general properties."""
-        [status, dnd_timer, clean_summary, consumable] = await asyncio.gather(
+        [status, clean_summary, consumable, dnd_timer, valley_electricity_timer] = await asyncio.gather(
             *[
                 self.get_status(),
-                self.get_dnd_timer(),
                 self.get_clean_summary(),
                 self.get_consumable(),
+                self.get_dnd_timer(),
+                self.get_valley_electricity_timer(),
             ]
         )
         last_clean_record = None
@@ -340,9 +341,10 @@ class RoborockClient:
         if any([status, dnd_timer, clean_summary, consumable]):
             return DeviceProp(
                 status,
-                dnd_timer,
                 clean_summary,
                 consumable,
+                dnd_timer,
+                valley_electricity_timer,
                 last_clean_record,
                 dock_summary,
             )
